@@ -8,11 +8,13 @@ import boto3
 import base64
 import json
 import os
+import sys
 import subprocess
 import dateutil
 from datetime import datetime
 import re
 import glob
+from multiprocessing import Process, Queue
 import requests
 import botocore
 import shutil
@@ -42,11 +44,9 @@ class AgentLifeCycle:
     restart(args):
         Stops and starts the containers listed in `COG_AGENT_CONTAINERS`.
     start(args):
-        Starts the containers listed in `COG_AGENT_CONTAINERS` and datadog. If `args` has parameter `list`, starts only containers in the list.
-        If `args` has parameter `datadog`/`agents` it will start only datadog/containers.
+        Starts the containers listed in `COG_AGENT_CONTAINERS`. If `args` has parameter `list`, starts only containers in the list.
     stop(args):
-        Stops the containers listed in `COG_AGENT_CONTAINERS` and datadog. If `args` has parameter `list`, stops only containers in the list.
-        If `args` has parameter `datadog`/`agents` it will stop only datadog/containers.
+        Stops the containers listed in `COG_AGENT_CONTAINERS`. If `args` has parameter `list`, stops only containers in the list.
     update(args):
         Pulls docker images listed in `COG_AGENT_IMAGES`.
     run_orbitty(args):
@@ -156,13 +156,11 @@ class AgentLifeCycle:
                 if container.status != "running":
                     print(bcolors.WARNING + "OFFLINE" + bcolors.ENDC)
                 else:
-                    if(container_name == "cgs_agent"):
+                    if(container_name == "cgs_diagnostics_agent"):
                         print(cgs_agent_status)
                     elif(container_name == "remote_intervention_agent"):
                         object._parse_remote_intervention_agent_logs(
                             container.logs(tail=50))
-                    elif(container_name == "cgs_diagnostics_agent"):
-                        print(cgs_agent_status)
                     else:
                         print(bcolors.OKBLUE + "ONLINE" + bcolors.ENDC)
             except docker.errors.NotFound:
@@ -235,7 +233,25 @@ class AgentLifeCycle:
                 break
         print(output_text)
 
-    def restart(object, args):
+    def _detached_restart(object,args):
+        """
+        Runs _restart_protocol in detached mode with printing muted.
+
+                Parameters:
+                        args: populated argument namespace returned by `argparse.parse_args()`
+                Returns:
+                        result (bool): True if succeeded
+        """
+
+        if os.fork() != 0:
+            return
+        sys.stdout = open(os.devnull, 'w')
+        result = object._restart_protocol(args)
+        sys.stdout = sys.__stdout__
+        return result
+
+
+    def _restart_protocol(object,args):
         """
         Stops and starts the containers listed in `COG_AGENT_CONTAINERS`.
 
@@ -248,10 +264,28 @@ class AgentLifeCycle:
         result = object.start(args)
         return result
 
+    def restart(object, args):
+        """
+        Stops and starts the containers listed in `COG_AGENT_CONTAINERS`.
+
+                Parameters:
+                        args: populated argument namespace returned by `argparse.parse_args()`
+                Returns:
+                        result (bool): True if succeeded in attached mode, always True in detached mode
+        """
+        if args.detach:
+            result = True
+            print("Running restart in detached mode")
+            p = Process(target=object._detached_restart,args=(args,))
+            p.start()
+        else:
+            result = object._restart_protocol(args)
+
+        return result
+
     def start(object, args):
         """
-        Starts the containers listed in `COG_AGENT_CONTAINERS` and datadog. If `args` has parameter `list`, starts only containers in the list.
-        If `args` has parameter `datadog`/`agents` it will start only datadog/containers.
+        Starts the containers listed in `COG_AGENT_CONTAINERS`. If `args` has parameter `list`, starts only containers in the list.
 
                 Parameters:
                         args: populated argument namespace returned by `argparse.parse_args()`
@@ -259,43 +293,22 @@ class AgentLifeCycle:
                         result (bool): True if succeeded
         """
         print("Called start")
-        if(args.agents or (hasattr(args, 'list') and len(args.list) > 0)):
-            print("Starting agents")
-            result = object.run_agents(args)
-        elif(args.datadog):
-            print("Starting datadog")
-            result = object.run_datadog(args)
-        else:
-            print("Starting agents")
-            result_agents = object.run_agents(args)
-            print("Starting datadog")
-            result_datadog = object.run_datadog(args)
-            result = result_agents and result_datadog
-
+        print("Starting agents")
+        result = object.run_agents(args)
         return result
 
     def stop(object, args):
         """
-        Stops the containers listed in `COG_AGENT_CONTAINERS` and datadog. If `args` has parameter `list`, stops only containers in the list.
-        If `args` has parameter `datadog`/`agents` it will stop only datadog/containers.
+        Stops the containers listed in `COG_AGENT_CONTAINERS`. If `args` has parameter `list`, stops only containers in the list.
 
                 Parameters:
                         args: populated argument namespace returned by `argparse.parse_args()`
                 Returns:
                         result (bool): True if succeeded
         """
-        if(args.agents or (hasattr(args, 'list') and len(args.list) > 0)):
-            print("Stopping agents")
-            result = object.remove_agents(args)
-        elif(args.datadog):
-            print("Stopping datadog")
-            result = object.stop_datadog(args)
-        else:
-            print("Stopping agents")
-            result_agents = object.remove_agents(args)
-            print("Stopping datadog")
-            result_datadog = object.stop_datadog(args)
-            result = result_agents and result_datadog
+
+        print("Stopping agents")
+        result = object.remove_agents(args)
         return result
 
     def status(object, args):
@@ -349,16 +362,12 @@ class AgentLifeCycle:
             args.list = object._docker_container_names
 
         object._agent_run_options = {}
-        object._agent_run_options["cgs_agent"] = {"command": "start_cognicept_agent.py", "volumes": {
-            args.config.config_path + "agent/logs/": {"bind": "/root/.cognicept/agent/logs", "mode": "rw"}}, "network_mode": "host"}
         object._agent_run_options["cgs_diagnostics_agent"] = {"command": "rosrun error_resolution_diagnoser error_resolution_diagnoser", "volumes": {
             args.config.config_path + "agent/logs/": {"bind": "/root/.cognicept/agent/logs", "mode": "rw"}}, "network_mode": "host"}
-        object._agent_run_options["ecs_server"] = {
-            "command": "/ecs_api_server/ecs_endpoint.py", "network_mode": "host"}
         object._agent_run_options["cgs_diagnostics_ecs_api"] = {
             "command": "/src/ecs_endpoint.py", "network_mode": "host"}
         object._agent_run_options["cgs_diagnostics_streamer_api"] = {"command": "/src/streamer_endpoint.py", "volumes": {
-            args.config.config_path + "runtime.env": {"bind": "/root/.cognicept/runtime.env", "mode": "rw"}}, "network_mode": "host"}
+            args.config.config_path + "agent/logs/bunched_logs": {"bind": "/root/.cognicept/agent/logs/bunched_logs", "mode": "rw"}}, "network_mode": "host"}
         object._agent_run_options["remote_intervention_agent"] = {
             "command": "rosrun remote_intervention_agent cognicept_agent_node", "network_mode": "host"}
 
@@ -417,32 +426,6 @@ class AgentLifeCycle:
                 success_flag = False
         return success_flag
 
-    def stop_datadog(object, args):
-        """
-        Stops datadog.
-
-                Parameters:
-                        args: populated argument namespace returned by `argparse.parse_args()`
-                Returns:
-                        result (bool): True if succeeded
-        """
-        sts = subprocess.call(['sudo','sh','-c', 'systemctl stop datadog-agent'] )
-        print("Health monitor agent stopped")
-        return True
-
-    def run_datadog(object, args):
-        """
-        Starts datadog.
-
-                Parameters:
-                        args: populated argument namespace returned by `argparse.parse_args()`
-                Returns:
-                        result (bool): True if succeeded
-        """
-        sts = subprocess.call(['sudo','sh','-c', 'systemctl start datadog-agent'])
-        print("Health monitor agent started")
-        return True
-
     def status_datadog(object, args):
         """
         Prints datadog status.
@@ -503,7 +486,7 @@ class AgentLifeCycle:
             print(bcolors.FAIL + "DOCKER ERROR" + bcolors.ENDC)
         os.system("xhost -local:root")
 
-    def update(object, args):
+    def _update_protocol(object, args):
         """
         Pulls docker images listed in `COG_AGENT_IMAGES`.
 
@@ -569,6 +552,44 @@ class AgentLifeCycle:
         print("Info: Run `cognicept restart` to redeploy updated agents.")
         return success_flag
 
+    def _detached_update(object,args):
+        """
+        Runs the _update_protocol that pulls docker images listed in `COG_AGENT_IMAGES`.
+
+                Parameters:
+                        args: populated argument namespace returned by `argparse.parse_args()`
+                Returns:
+                        result (bool): True if succeeded
+        """
+        if os.fork() != 0:
+            return
+
+        sys.stdout = open(os.devnull, 'w')
+
+        result = object._update_protocol(args)
+
+        sys.stdout = sys.__stdout__
+
+        return result
+
+    def update(object,args):
+        """
+        Pulls docker images listed in `COG_AGENT_IMAGES`. Can be run in detached mode where printing is muted
+
+                Parameters:
+                        args: populated argument namespace returned by `argparse.parse_args()`
+                Returns:
+                        result (bool): Always True if run in detached mode, otherwise True if successful
+        """
+        if args.detach:
+            result = True
+            print("Running update in detached mode")
+            p = Process(target=object._detached_update, args=(args,))
+            p.start()
+        else:
+            result = object._update_protocol(args)
+
+        return result
     def _construct_ecr_client(object, config_obj):
         """
         Member utility function to create ECR client `object.ecr_client` based on runtime.env credentials
