@@ -16,12 +16,12 @@ class bcolors:
 def generate_progress_bar(iteration, total, decimals=1, length=100, fill='█'):
     """
     Call in a loop to create terminal progress bar
-    @params:
-        iteration   - Required  : current iteration (Int)
-        total       - Required  : total iterations (Int)
-        decimals    - Optional  : positive number of decimals in percent complete (Int)
-        length      - Optional  : character length of bar (Int)
-        fill        - Optional  : bar fill character (Str)
+        Parameters:
+            iteration   - Required  : current iteration (Int)
+            total       - Required  : total iterations (Int)
+            decimals    - Optional  : positive number of decimals in percent complete (Int)
+            length      - Optional  : character length of bar (Int)
+            fill        - Optional  : bar fill character (Str)
     """
     percent = ("{0:." + str(decimals) + "f}").format(100 *
                                                      (iteration / float(total)))
