@@ -14,7 +14,6 @@ from cogniceptshell.pusher import Pusher
 
 
 def main():
-
     # Create the parser
     parser = argparse.ArgumentParser(
         description='Shell utility to configure Cognicept tools.')
@@ -53,11 +52,11 @@ def main():
     parser_config.add_argument(
         '--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
     parser_config.add_argument(
-        '--add',  help='Add new environmental variable in config file', action='store_true')
+        '--add', help='Add new environmental variable in config file', action='store_true')
     parser_config.add_argument(
-        '--ssh',  help='Configure ssh access during remote intervention', action='store_true')
+        '--ssh', help='Configure ssh access during remote intervention', action='store_true')
     parser_config.add_argument(
-        '--read',  help='Prints Cognicept configuration', action='store_true')
+        '--read', help='Prints Cognicept configuration', action='store_true')
 
     parser_keyrotate.set_defaults(func=local_cfg.cognicept_key_rotate)
     parser_keyrotate.add_argument(
@@ -73,40 +72,31 @@ def main():
         '--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
 
     parser_restart.set_defaults(func=agent_lifetime.restart)
+    parser_restart.add_argument('-d', '--detach', action='store_true',
+                                help='sets restart to be run in a detached manner. Progress will not be printed')
     parser_restart.add_argument(
         '--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
     parser_restart.add_argument(
         'list', help='List of agents to restart', metavar='list', type=str, nargs='*')
-    parser_restart.add_argument(
-        '--datadog', help='Restart only datadog agent', action='store_true')
-    parser_restart.add_argument(
-        '--agents', help='Restart only cognicept agents', action='store_true')
 
     parser_start.set_defaults(func=agent_lifetime.start)
     parser_start.add_argument(
         '--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
     parser_start.add_argument(
         'list', help='List of agents to start', metavar='list', type=str, nargs='*')
-    parser_start.add_argument(
-        '--datadog', help='Restart only datadog agent', action='store_true')
-    parser_start.add_argument(
-        '--agents', help='Restart only cognicept agents', action='store_true')
 
     parser_stop.set_defaults(func=agent_lifetime.stop)
     parser_stop.add_argument(
         '--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
     parser_stop.add_argument(
         'list', help='List of agents to stop', metavar='list', type=str, nargs='*')
-    parser_stop.add_argument(
-        '--datadog', help='Stop only datadog agent', action='store_true')
-    parser_stop.add_argument(
-        '--agents', help='Stop only cognicept agents', action='store_true')
 
     parser_update.set_defaults(func=agent_lifetime.update)
     parser_update.add_argument(
         '--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
     parser_update.add_argument(
         '--reset', help='Triggers new login before update', action='store_true')
+    parser_update.add_argument("-d", "--detach", help="Runs update in detached mode", action="store_true")
 
     parser_orbitty.set_defaults(func=agent_lifetime.run_orbitty)
     parser_orbitty.add_argument(
@@ -117,11 +107,15 @@ def main():
     parser_record.add_argument(
         '--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
     parser_record.add_argument(
-        '--start', help='Start rosbag recording session. Provide topics to record separated by spaces with their `/` prefix. e.g. cognicept record --start /rosout /odom', nargs='+')
+        '--start',
+        help='Start rosbag recording session. Provide topics to record separated by spaces with their `/` prefix. e.g. cognicept record --start /rosout /odom',
+        nargs='+')
     parser_record.add_argument(
         '--all', help='Start rosbag recording session to record ALL topics.', action='store_true')
     parser_record.add_argument(
-        '--stop', help='Stop rosbag recording session. Set `STOP` to `autopush` to automatically push latest bag to the Cognicept cloud after stopping', type=str, const='nopush', nargs='?')
+        '--stop',
+        help='Stop rosbag recording session. Set `STOP` to `autopush` to automatically push latest bag to the Cognicept cloud after stopping',
+        type=str, const='nopush', nargs='?')
     parser_record.add_argument(
         '--pause', help='Pause rosbag recording session', action='store_true')
     parser_record.add_argument(
@@ -134,9 +128,10 @@ def main():
     parser_push.add_argument(
         '--path', help='Cognicept configuration directory (default: `' + DEFAULT_PATH + '`)', default=DEFAULT_PATH)
     parser_push.add_argument(
-        '--bag', help='Pushes rosbag to the Cognicept cloud. By default it pushes the latest bag file recording. Set `BAG` to appropriate bag name in the `PATH` folder to upload a rosbag by name', type=str, const='latest', nargs='?')
+        '--bag',
+        help='Pushes rosbag to the Cognicept cloud. By default it pushes the latest bag file recording. Set `BAG` to appropriate bag name in the `PATH` folder to upload a rosbag by name',
+        type=str, const='latest', nargs='?')
 
-    
     parser_init.set_defaults(func=local_cfg.init_config)
     parser_init.add_argument(
         '--path', default=DEFAULT_PATH)
@@ -148,16 +143,16 @@ def main():
     # Parse the arguments
     args = parser.parse_args()
 
-    if("path" not in args):
+    if ("path" not in args):
         parser.print_help()
     else:
         local_cfg.load_config(args.path)
         agent_lifetime.configure_containers(local_cfg)
         args.config = local_cfg
 
-        if(hasattr(args, 'func')):
+        if (hasattr(args, 'func')):
             args.func(args)
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
